==> blizz_vanisher-7.x-1.0.tar.gz: blizz_vanisher/js/tarteaucitron/lang/tarteaucitron.de.js <==
/*global tarteaucitron */
tarteaucitron.lang = {
  "adblock": "Bitte deaktivieren Sie Ihren Adblocker! Mit einem aktiviertem Adblocker ist es nicht möglich die Datenschutzeinstellungen für diese Website zu personalisieren.",
  "adblock_call": "Bitte deaktivieren Sie Ihren Adblocker! Mit einem aktiviertem Adblocker ist es nicht möglich die Datenschutzeinstellungen für diese Website zu personalisieren.",
  "reload": "Bitte laden Sie die Seite neu.",

  "alertBigScroll": "Achtung! Wenn Sie diese Website benutzen, zum Beispiel durch scrollen, akzeptieren Sie die Verwendung von 'Cookies' durch externe Dienstleister. Verwenden Sie die Datenschutzeinstellungen, um Ihre Einstellungen zu personalisieren.",
  "alertBigClick": "Wenn Sie diese Website benutzen,",
  "alertBig": "stimmen Sie der Benutzung externer Dienste zu.",

  "alertBigPrivacy": "Diese Website verwendet 'Cookies'. In den Datenschutzeinstellungen können Sie bestimmen, welche Dienste verwendet/nicht verwendet werden dürfen.",
  "alertSmall": "Datenschutzeinstellungen",
  "personalize": "Personalisieren",
  "acceptAll": "OK, akzeptiere alles",
  "close": "Beenden",

  "all": "Datenschutzeinstellungen",

  "info": "Schutz der Privatsphäre",
  "disclaimer": "Wenn Sie diese Dienste nutzen (Opt-In) stimmen Sie zu, dass die für diese Dienste erforderlichen 'Cookies' und/oder Tracking-Funktionen gespeichert/verwendet werden.",
  "allow": "Erlauben",
  "deny": "Ablehnen",
  "noCookie": "Dieser Dienst verwendet keine 'Cookies'.",
  "useCookie": "Dieser Dienst beinhaltet",
  "useCookieCurrent": "Dieser Dienst hat ein 'Cookie' installiert",
  "useNoCookie": "Dieser Dienst hat keine 'Cookies' installiert.",
  "more": "Weiter lesen",
  "source": "Zur offiziellen Website",
  "credit": "Cookies-Manager von tarteaucitron.js",

  "fallback": "ist deaktiviert.",

  "ads": {
    "title": "Netzwerke für Werbeanzeigen",
    "details": "Netzwerke für Werbeanzeigen können mit dem Verkauf von Werbeplatzierungen auf dieser Website Einnahmen erzielen."
  },
  "analytic": {
    "title": "Besucher Zähldienste",
    "details": "Die verwendeten Besucherzähldienste generieren Statistiken, die dabei helfen diese Website zu verbessern."
  },
  "social": {
    "title": "Soziale Netzwerke",
    "details": "Soziale Netzwerke können die Benutzbarkeit der Website verbessern und ihren Bekanntheitsgrad erhöhen."
  },
  "video": {
    "title": "Video Plattformen",
    "details": "Video Plattformen ermöglichen externe Videoinhalte einzublenden und die Sichtbarkeit der Website zu erhöhen."
  },
  "comment": {
    "title": "Kommentarverwaltung",
    "details": "Kommentarverwaltungen erleichtern die Organisation von Kommentaren und helfen dabei Spam zu verhindern."
  },
  "support": {
    "title": "Support",
    "details": "Supportdienste erlauben es, die Urheber dieser Website zu kontaktieren und helfen dabei die Website zu verbessern."
  },
  "api": {
    "title": "APIs",
    "details": "APIs sind Programmteile, die internen Programmen die Anbindung an externe Dienste oder Daten ermöglichen. Sie verbessern und erweitern die Funktionalitäten der Website."
  },
  "other": {
    "title": "Andere",
    "details": "Dienste zum Anzeigen weiterer Webinhalte von externen Anbietern."
  }
};

==> blizz_vanisher-7.x-1.3.tar.gz: blizz_vanisher/js/tarteaucitron/lang/tarteaucitron.de.js <==
/*global tarteaucitron */
tarteaucitron.lang = {
  "adblock": "Bitte deaktivieren Sie Ihren Adblocker! Mit einem aktiviertem Adblocker ist es nicht möglich die Datenschutzeinstellungen für diese Website zu personalisieren.",
  "adblock_call": "Bitte deaktivieren Sie Ihren Adblocker!",
  "reload": "Bitte laden Sie die Seite neu.",

  "alertBigScroll": "Achtung! Wenn Sie diese Website benutzen, zum Beispiel durch scrollen, akzeptieren Sie die Verwendung von 'Cookies' durch externe Dienstleister. Verwenden Sie die Datenschutzeinstellungen, um Ihre Einstellungen zu personalisieren.",
  "alertBigClick": "Wenn Sie diese Website benutzen,",
  "alertBig": "stimmen Sie der Benutzung externer Dienste zu.",

  "alertBigPrivacy": "Diese Website verwendet 'Cookies'. In den Datenschutzeinstellungen können Sie bestimmen, welche Dienste verwendet/nicht verwendet werden dürfen.",
  "alertSmall": "Datenschutzeinstellungen",
  "personalize": "Personalisieren",
  "acceptAll": "OK, akzeptiere alles",
  "close": "Beenden",

  "all": "Datenschutzeinstellungen",

  "info": "Schutz der Privatsphäre",
  "disclaimer": "Wenn Sie diese Dienste nutzen (Opt-In) stimmen Sie zu, dass die für diese Dienste erforderlichen 'Cookies' und/oder Tracking-Funktionen gespeichert/verwendet werden.",
  "allow": "Erlauben",
  "deny": "Ablehnen",
  "noCookie": "Dieser Dienst verwendet keine 'Cookies'.",
  "useCookie": "Dieser Dienst beinhaltet",
  "useCookieCurrent": "Dieser Dienst hat 'Cookies' installiert: ",
  "useNoCookie": "Dieser Dienst hat keine 'Cookies' installiert.",
  "more": "Weiter lesen",
  "source": "Zur offiziellen Website",
  "credit": "Cookies-Manager von tarteaucitron.js",

  "fallback": "ist deaktiviert.",

  "ads": {
    "title": "Netzwerke für Werbeanzeigen",
    "details": "Netzwerke für Werbeanzeigen können mit dem Verkauf von Werbeplatzierungen auf dieser Website Einnahmen erzielen."
  },
  "analytic": {
    "title": "Besucher Zähldienste",
    "details": "Die verwendeten Besucherzähldienste generieren Statistiken, die dabei helfen diese Website zu verbessern."
  },
  "social": {
    "title": "Soziale Netzwerke",
    "details": "Soziale Netzwerke können die Benutzbarkeit der Website verbessern und ihren Bekanntheitsgrad erhöhen."
  },
  "video": {
    "title": "Video Plattformen",
    "details": "Video Plattformen ermöglichen externe Videoinhalte einzublenden und die Sichtbarkeit der Website zu erhöhen."
  },
  "comment": {
    "title": "Kommentarverwaltung",
    "details": "Kommentarverwaltungen erleichtern die Organisation von Kommentaren und helfen dabei Spam zu verhindern."
  },
  "support": {
    "title": "Support",
    "details": "Supportdienste erlauben es, die Urheber dieser Website zu kontaktieren und helfen dabei die Website zu verbessern."
  },
  "api": {
    "title": "APIs",
    "details": "APIs sind Programmteile, die internen Programmen die Anbindung an externe Dienste oder Daten ermöglichen. Sie verbessern und erweitern die Funktionalitäten der Website."
  },
  "other": {
    "title": "Andere",
    "details": "Dienste zum Anzeigen weiterer Webinhalte von externen Anbietern."
  }
};
